"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var table_results_page_1 = require("../table-results-page");
var footer_legend_1 = require("./footer-legend");
var PAGES_LIMIT = 6;
var FooterComponent = (function () {
    function FooterComponent() {
        this.onPageClicked = new core_1.EventEmitter();
    }
    FooterComponent.prototype.ngOnInit = function () {
    };
    FooterComponent.prototype.getPageBeginning = function () {
        return this.resultsPage.from + 1;
    };
    FooterComponent.prototype.getPageEnd = function () {
        return Math.min(this.resultsPage.from + this.resultsPage.count, this.resultsPage.total);
    };
    FooterComponent.prototype.getTotal = function () {
        return this.resultsPage.total;
    };
    FooterComponent.prototype.getPages = function () {
        var pages = [];
        var radio = PAGES_LIMIT / 2;
        var currentPage = this.currentPage;
        var totalPages = this.getTotalPages();
        var firstPage;
        var lastPage;
        if (totalPages - currentPage <= radio) {
            firstPage = Math.max(0, totalPages - PAGES_LIMIT);
            lastPage = totalPages;
        }
        else if (currentPage <= radio) {
            firstPage = 0;
            lastPage = Math.min(totalPages, PAGES_LIMIT);
        }
        else {
            firstPage = currentPage - radio;
            lastPage = currentPage + radio;
        }
        for (var i = firstPage; i < lastPage; i++) {
            pages.push(i + 1);
        }
        return pages;
    };
    FooterComponent.prototype.getTotalPages = function () {
        return Math.ceil((this.getTotal() / this.resultsPage.count));
    };
    FooterComponent.prototype.isFirstPageVisible = function () {
        var currentPage = this.getCurrentPage();
        return currentPage > PAGES_LIMIT / 2 && this.getTotalPages() > PAGES_LIMIT;
    };
    FooterComponent.prototype.isLastPageVisible = function () {
        var totalPages = this.getTotalPages();
        return totalPages - this.currentPage > PAGES_LIMIT / 2 && totalPages > PAGES_LIMIT;
    };
    FooterComponent.prototype.pageClicked = function (page) {
        this.currentPage = page - 1;
        this.onPageClicked.emit(page - 1);
    };
    FooterComponent.prototype.onFirstClicked = function () {
        this.currentPage = 0;
        this.onPageClicked.emit(this.currentPage);
    };
    FooterComponent.prototype.onLastClicked = function () {
        this.currentPage = this.getTotalPages() - 1;
        this.onPageClicked.emit(this.currentPage);
    };
    FooterComponent.prototype.getCurrentPage = function () {
        return this.currentPage;
    };
    FooterComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: 'ngx-iq-footer',
                    template: '<div class="row" *ngIf="getTotalPages() > 1"><div class="col-sm-6"><div class="pull-left"><div class="results-count" *ngIf="!getTotal() || getTotal() === 0">{{ footerLegend.noresults }}</div><div class="results-count" *ngIf="getTotal() && getTotal() > 0">{{ footerLegend.showingResults }} {{getPageBeginning()}} {{ footerLegend.to }} {{getPageEnd()}} {{ footerLegend.of }} {{getTotal()}}</div></div></div><div class="col-sm-6"><div class="pull-right"><nav aria-label="Page navigation"><ul class="pagination"><li><a (click)="onFirstClicked()" aria-label="First" *ngIf="isFirstPageVisible()"><span aria-hidden="true">&laquo;</span></a></li><li *ngFor="let item of getPages()" [class.active]="item === getCurrentPage() + 1"><a (click)="pageClicked(item)">{{item}}</a></li><li><a (click)="onLastClicked()" aria-label="Last" *ngIf="isLastPageVisible()"><span aria-hidden="true">&raquo;</span></a></li></ul></nav></div></div></div>',
                    styles: ['.results-count {    margin: 20px 0;    padding: 8px 0;}.pagination a {    cursor: pointer;}']
                },] },
    ];
    FooterComponent.ctorParameters = function () { return []; };
    FooterComponent.propDecorators = {
        "resultsPage": [{ type: core_1.Input },],
        "onPageClicked": [{ type: core_1.Output },],
        "footerLegend": [{ type: core_1.Input },],
        "currentPage": [{ type: core_1.Input },],
    };
    return FooterComponent;
}());
exports.FooterComponent = FooterComponent;
//# sourceMappingURL=footer.component.js.map