"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var table_results_page_1 = require("../table-results-page");
var page_request_data_1 = require("../page-request-data");
var footer_legend_1 = require("../footer/footer-legend");
var table_state_service_1 = require("../table-state.service");
var TableComponent = (function () {
    function TableComponent(tableStateService) {
        this.tableStateService = tableStateService;
        this.columns = [];
        this.footerLegend = {
            showingResults: 'Showing results',
            of: 'of',
            to: 'to',
            noresults: 'No results'
        };
        this.currentPage = 0;
        this.columnOrdering = [];
    }
    TableComponent.prototype.ngOnInit = function () {
        this.resultsPage = new table_results_page_1.TableResultsPage();
        this.resolveInitialPagination();
        this.loadData(this.buildDataRequestConfig());
    };
    TableComponent.prototype.resolveInitialPagination = function () {
        if (this.tableId) {
            var tableState = this.tableStateService.state[this.tableId];
            if (tableState) {
                this.loadState(tableState);
            }
            else {
                this.saveState();
            }
        }
    };
    TableComponent.prototype.loadState = function (tableState) {
        this.columnOrdering = tableState.ordering;
        this.currentPage = tableState.currentPage;
    };
    TableComponent.prototype.saveState = function () {
        this.tableStateService.state[this.tableId] = {
            currentPage: this.currentPage,
            ordering: this.columnOrdering
        };
    };
    TableComponent.prototype.onPageClicked = function (page) {
        this.currentPage = page;
        if (this.tableId) {
            this.saveState();
        }
        var drc = this.buildDataRequestConfig();
        this.loadData(drc);
    };
    TableComponent.prototype.sort = function (prop) {
        if (this.columnOrdering.length === 0) {
            this.columnOrdering.push({
                property: prop,
                direction: 'asc'
            });
        }
        else {
            var indexToRemove_1 = -1;
            this.columnOrdering.forEach(function (columnOrder, index) {
                if (columnOrder.property === prop) {
                    indexToRemove_1 = index;
                }
            });
            if (indexToRemove_1 > 0) {
                var previousDirection = this.columnOrdering[indexToRemove_1].direction;
                this.columnOrdering.splice(indexToRemove_1, 1);
                this.columnOrdering.splice(0, 0, {
                    property: prop,
                    direction: previousDirection === 'asc' ? 'desc' : 'asc'
                });
            }
            else if (indexToRemove_1 === 0) {
                var previousDirection = this.columnOrdering[indexToRemove_1].direction;
                this.columnOrdering[indexToRemove_1].direction = previousDirection === 'asc' ? 'desc' : 'asc';
            }
            else {
                this.columnOrdering.splice(0, 0, {
                    property: prop,
                    direction: 'asc'
                });
            }
        }
        var drc = this.buildDataRequestConfig();
        this.loadData(drc);
    };
    TableComponent.prototype.buildDataRequestConfig = function () {
        var drc = new page_request_data_1.PageRequestData();
        drc.from = this.currentPage * this.pageSize;
        drc.count = this.pageSize;
        drc.orderBy = this.columnOrdering;
        return drc;
    };
    TableComponent.prototype.loadData = function (requestPageData) {
        var _this = this;
        this.dataSource(requestPageData)
            .subscribe(function (resultsPage) { return _this.resultsPage = resultsPage; });
    };
    TableComponent.prototype.refreshData = function () {
        this.loadData(this.buildDataRequestConfig());
    };
    TableComponent.prototype.getSortDirection = function (column) {
        var sortDirection;
        this.columnOrdering
            .forEach(function (c) {
            if (column.prop === c.property) {
                sortDirection = c.direction;
            }
        });
        return sortDirection;
    };
    TableComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: 'ngx-iq-table',
                    template: '<table class="table"><thead><tr class="header"><th *ngFor="let column of columns" [style.width]="column.width + \'\' + column.widthUnit + \'\'" [class]="column.css"><div *ngIf="column.prop !== undefined" class="sortable"><a (click)="sort(column.prop)">{{column.name}} </a><i class="glyphicon glyphicon-chevron-up icon" *ngIf="getSortDirection(column) === \'asc\'"></i> <i class="glyphicon glyphicon-chevron-down icon" *ngIf="getSortDirection(column) === \'desc\'"></i></div><div *ngIf="column.prop === undefined"><span>{{column.name}}</span></div></th></tr></thead><tbody><ng-template ngFor [ngForOf]="resultsPage.results" [ngForTemplate]="rows"></ng-template></tbody></table><ngx-iq-footer [resultsPage]="resultsPage" [currentPage]="currentPage" (onPageClicked)="onPageClicked($event)" [footerLegend]="footerLegend"></ngx-iq-footer>',
                    styles: ['.header th{    border-bottom: 2px solid #dddddd;}.table>tbody>tr>td {    border-top: 1px dotted #ddd;}.sortable .icon {    font-weight: bolder;    color: #d6d6d6;    font-size: 10px;}.sortable a {    cursor: pointer;}.sortable a:hover {    text-decoration: none;}']
                },] },
    ];
    TableComponent.ctorParameters = function () { return [
        { type: table_state_service_1.TableStateService, },
    ]; };
    TableComponent.propDecorators = {
        "tableId": [{ type: core_1.Input },],
        "dataSource": [{ type: core_1.Input },],
        "columns": [{ type: core_1.Input },],
        "pageSize": [{ type: core_1.Input },],
        "footerLegend": [{ type: core_1.Input },],
        "currentPage": [{ type: core_1.Input },],
        "rows": [{ type: core_1.ContentChild, args: ['rows',] },],
    };
    return TableComponent;
}());
exports.TableComponent = TableComponent;
//# sourceMappingURL=table.component.js.map